aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/core/platform/test.h
diff options
context:
space:
mode:
Diffstat (limited to 'tensorflow/core/platform/test.h')
-rw-r--r--tensorflow/core/platform/test.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/tensorflow/core/platform/test.h b/tensorflow/core/platform/test.h
index 73f2f1e272..9f63d8c777 100644
--- a/tensorflow/core/platform/test.h
+++ b/tensorflow/core/platform/test.h
@@ -35,8 +35,9 @@ namespace testing {
// Return a temporary directory suitable for temporary testing files.
string TmpDir();
-// Returns the source directory containing data dependencies.
-string SrcDir();
+// Returns the path to TensorFlow in the directory containing data
+// dependencies.
+string TensorFlowSrcRoot();
// Return a random number generator seed to use in randomized tests.
// Returns the same value for the lifetime of the process.